@@ -5,13 +5,14 @@ import pprint
 import resource 
 import json
 import sys
+import webbrowser
 
 import requests
 from requests.auth import HTTPBasicAuth
 import yaml
 import time
 
-VERSION = '0.1.6'
+VERSION = '0.2.0'
 
 default_backliftURL = 'https://www.backlift.com/'
 backlift_configfile = '.backlift'
@@ -56,6 +57,11 @@ ERR_403 =      "Ooops! This action is forbidden. Either you haven't\n" +\
 ERR_RESPONSE = "Oops! Something is wrong with the server. Please send an\n"+\
                "angry email to %s." % backlift_email
 
+ERR_NOURL =    "Oops! This app doesn't have a valid URL. Have you pushed\n"+\
+               "your app to backlift yet? (See backlift --help) If you\n"+\
+               "have pushed your app and you're still getting this error,\n"+\
+               "please let us know by sending an email to %s." % backlift_email
+
 
 ## UTILITIES ------------------------------------------------------------------
 
@@ -207,6 +213,22 @@ def register_key(key):
         fail(ERR_SERVER)
 
 
+def get_app_meta(api_key, app_id):
+    try:
+        # import pdb; pdb.set_trace()
+        r = requests.get(backliftURL_getappmeta % app_id, 
+                          auth=HTTPBasicAuth('api', api_key), verify=False)
+        check_response(r)
+
+        r = json.loads(r.text)
+        return r
+
+    except requests.exceptions.ConnectionError:
+        fail(ERR_SERVER)
+
+    return None
+
+
 def create_app(api_key):
     try:
         # import pdb; pdb.set_trace()
@@ -342,8 +364,6 @@ def watch(path, skip_hidden):
 
     # import pdb; pdb.set_trace()
 
-    api_key = read_api_key()
-
     id = push(path, skip_hidden)
 
     before, configfile = scanFiles(path, skip_hidden)
@@ -371,6 +391,28 @@ def watch(path, skip_hidden):
         pass
 
 
+def open_browser(path, admin=False):
+
+    # import pdb; pdb.set_trace()
+
+    api_key = read_api_key()
+
+    cfg_path = os.path.normpath(os.path.abspath(
+        os.path.join(path, backlift_configfile)))
+
+    app_id = get_id(cfg_path)
+
+    meta = get_app_meta(api_key, app_id)
+
+    if admin:
+        url = meta.get('admin_url', '')
+    else:
+        url = meta.get('app_url', '')
+
+    if not url:
+        fail(ERR_NOURL)
+
+    webbrowser.open_new_tab(url)
 
 
 ## MAIN -----------------------------------------------------------------------
@@ -379,6 +421,7 @@ def execute_command_line():
 
     global backliftURL
     global backliftURL_registerkey
+    global backliftURL_getappmeta
     global backliftURL_createapp
     global backliftURL_templatefiles
     global backliftURL_upload
@@ -390,7 +433,9 @@ def execute_command_line():
         '  create:TYPE NAME\tCreate a new backlift app using the TYPE template\n' +\
         '  init\t\t\tInitialize backlift for an existing app\n' +\
         '  push\t\t\tPush files up to backlift\n' +\
-        '  watch\t\t\tObserve path and push files to backlift whenever they change'
+        '  watch\t\t\tObserve path and push files to backlift whenever they change\n' +\
+        '  open\t\t\tOpen an app using the default browser\n' +\
+        '  admin\t\t\tOpen an app\'s admin page using the default browser'
 
     parser = optparse.OptionParser(usagetxt, version='%prog cli '+VERSION)
 
@@ -407,6 +452,7 @@ def execute_command_line():
 
     backliftURL = options.url
     backliftURL_registerkey = os.path.join(backliftURL, 'register-early')
+    backliftURL_getappmeta = os.path.join(backliftURL, 'app-admin/%s')
     backliftURL_createapp = os.path.join(backliftURL, 'app-admin')
     backliftURL_templatefiles = os.path.join(backliftURL, 'app-templates')
     backliftURL_upload = os.path.join(backliftURL, 'app-admin/%s')
@@ -430,6 +476,10 @@ def execute_command_line():
                     create(options.path, args[1], 'basic')
         elif args[0].lower() == 'init':
             init(options.path)
+        elif args[0].lower() == 'open':
+            open_browser(options.path)
+        elif args[0].lower() == 'admin':
+            open_browser(options.path, admin=True)
         elif args[0].lower() == 'push':
             push(options.path, options.skip_hidden)
         elif args[0].lower() == 'watch':
